Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(448)

Unified Diff: content/renderer/gpu/command_buffer_proxy.h

Issue 9192014: Replace WGC3D visibility extension with resource_usage extension. [Part 2 of 3] (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Added image_transport_surface_win changes Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/gpu/image_transport_surface_win.cc ('k') | content/renderer/gpu/command_buffer_proxy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/gpu/command_buffer_proxy.h
diff --git a/content/renderer/gpu/command_buffer_proxy.h b/content/renderer/gpu/command_buffer_proxy.h
index 7c9778e769961c016fa7cd7862cd015d6a95aacb..f154eda2e8df37948fd3c803c23cb5d29eb08fc5 100644
--- a/content/renderer/gpu/command_buffer_proxy.h
+++ b/content/renderer/gpu/command_buffer_proxy.h
@@ -19,6 +19,7 @@
#include "gpu/command_buffer/common/command_buffer.h"
#include "ipc/ipc_channel.h"
#include "ipc/ipc_message.h"
+#include "ui/gfx/gl/gl_surface.h"
class GpuChannelHost;
struct GPUCommandBufferConsoleMessage;
@@ -65,8 +66,8 @@ class CommandBufferProxy : public gpu::CommandBuffer,
// the task whether the echo succeeds or not.
bool Echo(const base::Closure& callback);
- // Sends an IPC message with the new state of surface visibility
- bool SetSurfaceVisible(bool visible);
+ // Sends an IPC message with the new state of resource usage
+ bool SetResourceUsage(gfx::GLSurface::ResourceUsage resourceUsage);
// Reparent a command buffer. TODO(apatrick): going forward, the notion of
// the parent / child relationship between command buffers is going away in
« no previous file with comments | « content/common/gpu/image_transport_surface_win.cc ('k') | content/renderer/gpu/command_buffer_proxy.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698